@@ -24,10 +24,23 @@ from codenerix_payments.views import PaymentRequestList, PaymentRequestCreate, P
     PaymentConfirmationList, PaymentAnswerList, PaymentAction, \
     PaymentRequestDetail, PaymentConfirmationDetail, PaymentAnswerDetail, PaymentPlatforms, PaymentConfirmationAutorender
 
+from codenerix_payments.views import CurrencyList, CurrencyCreate, CurrencyDetail, CurrencyUpdate, CurrencyDelete
+from codenerix_payments.views import Verifysign
+
 
 urlpatterns = [
+    url(r'^verify_sign$', Verifysign.as_view(), name='verify_sign'),
+
+    url(r'^currencys$', CurrencyList.as_view(), name='currency_list'),
+    url(r'^currencys/add$', CurrencyCreate.as_view(), name='currency_add'),
+    url(r'^currencys/(?P<pk>\w+)$', CurrencyDetail.as_view(), name='currency_detail'),
+    url(r'^currencys/(?P<pk>\w+)/edit$', CurrencyUpdate.as_view(), name='currency_edit'),
+    url(r'^currencys/(?P<pk>\w+)/delete$', CurrencyDelete.as_view(), name='currency_delete'),
+
+
     url(r'^paymentrequests$', PaymentRequestList.as_view(), name='paymentrequest_list'),
     url(r'^paymentrequests/add$', PaymentRequestCreate.as_view(), name='paymentrequest_add'),
+    url(r'^paymentrequests/locate/(?P<locator>[a-zA-Z0-9+/]+)$', PaymentRequestDetail.as_view(), {'pk': 0}, name='CNDX_paymenrequest_detail_locator'),
     url(r'^paymentrequests/(?P<pk>\w+)$', PaymentRequestDetail.as_view(), name='paymentrequest_detail'),
     url(r'^paymentrequests/(?P<pk>\w+)/edit$', PaymentRequestUpdate.as_view(), name='paymentrequest_edit'),
     url(r'^paymentrequests/(?P<pk>\w+)/delete$', PaymentRequestDelete.as_view(), name='paymentrequest_delete'),
@@ -38,4 +51,5 @@ urlpatterns = [
     url(r'^action/(?P<locator>[a-zA-Z0-9+/]+)/(?P<action>\w+)/$', PaymentAction.as_view(), name='payment_url'),
     url(r'^platforms/(?P<search>[\w\W]+|\*)$', PaymentPlatforms.as_view(), name='CDNX_payments_platforms'),
     url(r'^confirmation/(?P<locator>[a-zA-Z0-9+/]+)/(?P<action>\w+)/(?P<error>\w+)$', PaymentConfirmationAutorender.as_view(), name='CNDX_payments_confirmation'),
+    url(r'^confirmation/(?P<locator>[a-zA-Z0-9+/]+)/(?P<action>\w+)/(?P<error>\w+)/(?P<errortxt>.+)$', PaymentConfirmationAutorender.as_view(), name='CNDX_payments_confirmation'),
 ]
